# Copyright 2026 Flyto2. Licensed under Apache-2.0. See LICENSE.

"""
Google Workspace Integration Modules
Gmail send/search, Calendar create/list events
"""

from .gmail_send import *
from .gmail_search import *
from .calendar_create import *
from .calendar_list import *

__all__ = [
    # Google Workspace modules will be auto-discovered by module registry
]
